@@ -1,7 +1,7 @@
 from base import BaseParser
 import re
 from dofler.log import log
-import dofler.api.client
+import dofler.api
 
 class Parser(BaseParser):
     '''The Ettercap password parser.'''
@@ -11,7 +11,7 @@ class Parser(BaseParser):
     rproto = re.compile(r'^(\w*) : ')       # PROTO Regex: Pulls the protocal.
     promisc = {True: '', False: '-p'}       # Promiscuous flags.
     cmd = 'ettercap {PROMISC} -Tzuqi {INTERFACE}'   # Command to run.
-    stanza = 'Ettercap'
+    stanza = 'ettercap'
 
     def parse(self, line):
         '''Ettercap line output parser.'''
@@ -31,5 +31,5 @@ class Parser(BaseParser):
                 if str(proto) != 'HTTP':
                     og.debug('%s is sending Account <%s>' % (self.stanza, 
                                                              username))
-                    dofler.api.client.account(username, password, 
-                                              info, proto, 'ettercap')
\ No newline at end of file
+                    dofler.api.account(username, password, 
+                                       info, proto, 'ettercap')
\ No newline at end of file
